pub struct BiteOpt { /* private fields */ }Implementations
Sourceimpl BiteOpt
impl BiteOpt
pub fn new( lower: &[f64], upper: &[f64], init: Option<&[f64]>, p: &BiteParams, ) -> Self
Sourcepub fn ask(&mut self, batch: usize) -> Vec<Vec<f64>>
pub fn ask(&mut self, batch: usize) -> Vec<Vec<f64>>
Ask for up to batch candidate rows (real-valued). During the initial
population fill the batch is capped to the remaining init members.
pub fn current_batch_size(&self) -> usize
pub fn dim(&self) -> usize
pub fn population_size(&self) -> usize
pub fn stop_code(&self) -> i32
pub fn result_public(&self) -> BiteResult
Sourcepub fn optimize(&mut self, obj: &impl Objective) -> BiteResult
pub fn optimize(&mut self, obj: &impl Objective) -> BiteResult
Run until the evaluation budget or a stop condition is reached.