Function diversify_batch
Source pub fn diversify_batch(
archive: &mut Archive,
fitness: &mut dyn QdBatchFitness,
lower: &[f64],
upper: &[f64],
p: &DiversifierParams,
rng: &mut Rng,
) -> Result<(Vec<f64>, f64), &'static str>
Batch-evaluation variant of diversify. CMA-ES asks and tells remain
serial while each requested population can be evaluated concurrently.
Errors
Returns an error if fitness does not return one result per requested
candidate.