pub struct Mode { /* private fields */ }Implementations
Sourceimpl Mode
impl Mode
Sourcepub fn try_new(
fitfun: Fitness,
nobj: usize,
ncon: usize,
ints: Option<Vec<bool>>,
p: &ModeParams,
) -> Result<Self, &'static str>
pub fn try_new( fitfun: Fitness, nobj: usize, ncon: usize, ints: Option<Vec<bool>>, p: &ModeParams, ) -> Result<Self, &'static str>
Construct MODE after validating dimensions, bounds, population size, probabilities, and the optional integer mask.
Sourcepub fn new(
fitfun: Fitness,
nobj: usize,
ncon: usize,
ints: Option<Vec<bool>>,
p: &ModeParams,
) -> Self
pub fn new( fitfun: Fitness, nobj: usize, ncon: usize, ints: Option<Vec<bool>>, p: &ModeParams, ) -> Self
Construct MODE, panicking on invalid configuration. Applications that
accept user input should prefer Mode::try_new.
pub fn dim(&self) -> usize
pub fn nobj(&self) -> usize
pub fn ncon(&self) -> usize
pub fn popsize(&self) -> usize
pub fn stop(&self) -> i32
Sourcepub fn try_ask(&mut self) -> Result<Vec<Vec<f64>>, &'static str>
pub fn try_ask(&mut self) -> Result<Vec<Vec<f64>>, &'static str>
Fallible ask variant for interfaces that need to report call-order errors rather than panic.
Sourcepub fn tell(&mut self, ys: &[Vec<f64>]) -> i32
pub fn tell(&mut self, ys: &[Vec<f64>]) -> i32
Tell objective+constraint values for the offspring from ask.
Sourcepub fn try_tell(&mut self, ys: &[Vec<f64>]) -> Result<i32, &'static str>
pub fn try_tell(&mut self, ys: &[Vec<f64>]) -> Result<i32, &'static str>
Fallible tell variant validating call order and matrix shape.
Sourcepub fn tell_switch(
&mut self,
ys: &[Vec<f64>],
nsga_update: bool,
pareto_update: f64,
) -> i32
pub fn tell_switch( &mut self, ys: &[Vec<f64>], nsga_update: bool, pareto_update: f64, ) -> i32
Tell with a switched update mode (the C++ tell_switch).
pub fn try_tell_switch( &mut self, ys: &[Vec<f64>], nsga_update: bool, pareto_update: f64, ) -> Result<i32, &'static str>
Sourcepub fn set_population(&mut self, xs: &[Vec<f64>], ys: &[Vec<f64>]) -> i32
pub fn set_population(&mut self, xs: &[Vec<f64>], ys: &[Vec<f64>]) -> i32
Replace the population/offspring and tell (the C++ set_population).
pub fn try_set_population( &mut self, xs: &[Vec<f64>], ys: &[Vec<f64>], ) -> Result<i32, &'static str>
Sourcepub fn population(&self) -> Vec<Vec<f64>>
pub fn population(&self) -> Vec<Vec<f64>>
Current population (rows = individuals).
pub fn result(&self) -> ModeResult